pub struct HostState {
pub bridge: Arc<dyn Bridge>,
pub observations: Arc<Mutex<Vec<Observation>>>,
pub context_id: ContextId,
pub config: SandboxConfig,
}Expand description
Host state accessible from WASM imported functions.
The bridge and observations fields are accessed via Arc clones
captured by the linker closures, not through the struct directly.
The struct owns them to keep them alive for the store’s lifetime.
Fields
bridge: Arc<dyn Bridge>observations: Arc<Mutex<Vec<Observation>>>context_id: ContextIdconfig: SandboxConfigAuto Trait Implementations
impl Freeze for HostState
impl !RefUnwindSafe for HostState
impl Send for HostState
impl Sync for HostState
impl Unpin for HostState
impl UnsafeUnpin for HostState
impl !UnwindSafe for HostState